const { resolve } = require('./utils')
const ExtractTextPlugin = require('extract-text-webpack-plugin')
const DefinePlugin = require('webpack/lib/DefinePlugin')
const BabelMinify = require('babel-minify-webpack-plugin')

module.exports = function(platform, action) {
  return {
    stats: 'errors-only',
    context: resolve('./src'),
    entry: resolve('./src/app.js'),
    output: { filename: `app.${platform}.js` },
    module: {
      rules: [
        { test: /\.js$/, exclude: /node_modules/, loader: 'babel-loader' },
        {
          test: /\.vue$/,
          loaders: [
            { loader: 'vue-loader', options: { extractCSS: true } },
            { loader: resolve('./loader', false) }
          ]
        }
      ]
    },
    resolve: { extensions: ['.js', '.vue', '.scss', '.sass'] },
    plugins:
      action === 'build'
        ? [
            new BabelMinify(),
            new ExtractTextPlugin({
              filename: `app.${platform}.css`
            }),
            new DefinePlugin({
              CURRENT_PLATFORM: JSON.stringify(platform)
            })
          ]
        : [
            new ExtractTextPlugin({
              filename: `app.${platform}.css`
            }),
            new DefinePlugin({
              CURRENT_PLATFORM: JSON.stringify(platform)
            })
          ],
    stats: 'minimal'
  }
}
