const path = require('path')
const fs = require('fs')

const resolve = (p, root = true) => {
  return path.resolve(root ? process.cwd() : __dirname, p)
}

const package = require(resolve('package.json'))

const check = () => {
  if (!fs.existsSync(resolve('App_Resources'))) {
    throw new Error(
      'Directory "App_resources" is required in your root folder.'
    )
  } else if (!fs.existsSync(resolve('src/assets'))) {
    throw new Error('Directory "assets" is required in your "src" folder.')
  } else if (!package.nativescript || !package.nativescript.id) {
    throw new Error('Your need to specific your App ID in your package.json.')
  }
}

const stringify = (json, modifier = {}) => {
  return JSON.stringify(merge(json, modifier), null, 2)
}

const parse = content => {
  return JSON.parse(
    Buffer.isBuffer(content) ? content.toString() : JSON.stringify(content)
  )
}

const merge = (content, modifier) => {
  return { ...content, ...modifier }
}

const nativeDep = package => {
  const dependencies = parse(package).dependencies
  return Object.keys(dependencies)
    .filter(d => d.startsWith('nativescript-') || d === 'tns-core-modules')
    .reduce((obj, key) => ({ ...obj, [key]: dependencies[key] }), {})
}

const appify = content => {
  if (content.includes('{{ app_name }}')) {
    content = content
      .toString()
      .replace(/{{ app_name }}/g, package.name)
      .replace(/{{ version }}/g, package.version)
  }
  return content
}

const packageify = (content, minimal = false) => {
  content = parse(content)
  return minimal
    ? { name: content.name, version: content.version }
    : {
        name: content.name,
        version: content.version,
        description: content.description,
        license: content.license,
        readme: content.readme,
        nativescript: content.nativescript
      }
}

module.exports = {
  check,
  resolve,
  stringify,
  parse,
  merge,
  nativeDep,
  appify,
  packageify
}
