const { resolve } = require('./utils')
const HtmlWebpackPlugin = require('html-webpack-plugin')
const CopyWebpackPlugin = require('copy-webpack-plugin')
const WebpackShellPlugin = require('webpack-synchronizable-shell-plugin')

module.exports = (platform, action) => ({
  target: 'web',
  devServer: {
    contentBase: resolve('./dist/web'),
    compress: true,
    port: 9000,
    stats: 'errors-only'
  },
  output: {
    path: resolve('./dist/web')
  },
  resolve: {
    alias: {
      vue$: 'vue/dist/vue.js'
    },
    modules: ['node_modules']
  },
  plugins: [
    new WebpackShellPlugin({
      safe: true,
      onBuildStart: {
        scripts: ['echo "\n\x1b[33m------------ WEB ------------\x1b[0m\n"']
      }
    }),
    new HtmlWebpackPlugin({
      template: resolve('index.html')
    }),
    new CopyWebpackPlugin([
      {
        from: resolve('src/assets'),
        to: resolve('dist/web/assets')
      }
    ])
  ]
})
